@@ -1,7 +1,8 @@
 """TinyTinyEdit -- A minimal Document-based Cocoa application."""
 
-from Cocoa import *
+from Cocoa import NSDocument
 from PyObjCTools import AppHelper
+import objc
 import sys
 
 class TinyTinyDocument(NSDocument):
@@ -39,8 +40,8 @@ class TinyTinyDocument(NSDocument):
                 maxint = sys.maxsize
                 maxint_label = 'maxsize'
 
-            self.textView.setString_("Welcome to TinyTinyEdit in Python\nVersion: %s\nsys.%s: %d\nbyteorder: %s"%(
-                sys.version, maxint_label, maxint, sys.byteorder))
+            self.textView.setString_("Welcome to TinyTinyEdit in Python\nVersion: %s\nsys.%s: %d\nbyteorder: %s\nflags: %s"%(
+                sys.version, maxint_label, maxint, sys.byteorder, sys.flags))
 
     def readFromUTF8(self, path):
         f = file(path)
